@@ -6,29 +6,23 @@ from vfunctions_sdk import connection
 from vfunctions_sdk import NSM
 from vfunctions_sdk import publish
 
-class VFunction():
+class FunctionParams():
     def __init__(self):
         self.nsm = NSM.NSM()
 
         self.client_socket = connection.Vsock_connection()
+
         # Get message from the host
-        print("Getting data from host")
         request_data = self.client_socket.get_message()
 
-        print(request_data)
         self.params = request_data["params"]
 
         aws_credentials = request_data["awsCredentials"]
 
         self.aws_credentials = aws_credentials
 
-        self.region = aws_credentials["Region"]
-        self.aws_access_key_id = aws_credentials["AccessKeyId"]
-        self.aws_secret_access_key = aws_credentials["SecretAccessKey"]
-        self.aws_session_token = aws_credentials["SessionToken"]
 
-
-    def get_attestation_doc_for_credentials(self):
+    def get_attestation_doc_for_secrets(self):
 
         attestation_doc = self.nsm.get_attestation_doc(
             public_key=self.nsm._public_key)
@@ -52,9 +46,12 @@ class VFunction():
         return json.loads(self.nsm.decrypt(cipherdata))
 
 
-    def email_results(self, recipient, att_doc_b64):
+    def email_results(self, recipient, data_to_sign):
+        att_doc_b64 = self.sign_results(data_to_sign)
         encoded_att_doc = str.encode(att_doc_b64)
-        publish.send_email(recipient, encoded_att_doc, self.aws_credentials)
+
+        publisher = publish.Publisher(self.aws_credentials)
+        publisher.send_email(recipient, encoded_att_doc)
 
 
     def close(self):
